![pycoQC](https://raw.githubusercontent.com/a-slide/pycoQC/master/docs/pictures/pycoQC_long.png)

[![JOSS](http://joss.theoj.org/papers/ea8e08dc950622bdd5d16a65649954aa/status.svg)](http://joss.theoj.org/papers/ea8e08dc950622bdd5d16a65649954aa)
[![DOI](https://zenodo.org/badge/94531811.svg)](https://zenodo.org/badge/latestdoi/94531811)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/pycoQC/community?utm_source=share-link&utm_medium=link&utm_campaign=share-link)

[![GitHub license](https://img.shields.io/github/license/a-slide/pycoQC.svg)](https://github.com/a-slide/pycoQC/blob/master/LICENSE)
[![Language](https://raw.githubusercontent.com/a-slide/pycoQC/master/docs/pictures/language-Python3-brightgreen.png)](https://www.python.org/)
[![PyPI version](https://badge.fury.io/py/pycoQC.svg)](https://badge.fury.io/py/pycoQC)
[![Downloads](https://pepy.tech/badge/pycoqc)](https://pepy.tech/project/pycoqc)

---

**Full documentation is available at https://a-slide.github.io/pycoQC/**

---

**PycoQC computes metrics and generates interactive QC plots for Oxford Nanopore technologies sequencing data**

PycoQC relies on the *sequencing_summary.txt* file generated by Albacore and Guppy, but if needed it can also generates a summary file from basecalled fast5 files. The package supports 1D and 1D2 runs generated with Minion, Gridion and Promethion devices and basecalled with Albacore 1.2.1+ or Guppy 2.1.3+. PycoQC is written in pure Python3. **Python 2 is not supported**.

# Gallery

**Click on a picture to access an online interactive version editable with [plotly chart studio](https://plot.ly/online-chart-maker/)**

[![summary](./docs/pictures/summary.gif)](https://plot.ly/~aleg/16/)

[![reads_len_1D_example](./docs/pictures/reads_len_1D.gif)](https://plot.ly/~aleg/2/distribution-of-read-length/)

[![reads_len_1D_example](./docs/pictures/reads_qual_1D.gif)](https://plot.ly/~aleg/66/distribution-of-read-quality-scores/)

[![reads_qual_len_2D_example](./docs/pictures/reads_qual_len_2D.gif)](https://plot.ly/~aleg/3/mean-read-quality-per-sequence-length/)

[![channels_activity](./docs/pictures/channels_activity.gif)](https://plot.ly/~aleg/4/output-per-channel-over-experiment-time/)

[![output_over_time](./docs/pictures/output_over_time.gif)](https://plot.ly/~aleg/5/output-over-experiment-time/)

[![qual_over_time](./docs/pictures/qual_over_time.gif)](https://plot.ly/~aleg/6/mean-read-quality-over-experiment-time/)

[![len_over_time](./docs/pictures/len_over_time.gif)](https://plot.ly/~aleg/28/read-length-over-experiment-time/)

[![barcode_counts](./docs/pictures/barcode_counts.gif)](https://plot.ly/~aleg/7/percentage-of-reads-per-barcode/)

## Example HTML reports

* [Albacore-1.2.1_basecall-1D-DNA](https://a-slide.github.io/pycoQC/demo/data/output/Albacore-1.2.1_basecall-1D-DNA.html)

* [Albacore-1.7.0_basecall-1D-DNA](https://a-slide.github.io/pycoQC/demo/data/output/Albacore-1.7.0_basecall-1D-DNA.html)

* [Albacore-2.1.10_basecall-1D-DNA](https://a-slide.github.io/pycoQC/demo/data/output/Albacore-2.1.10_basecall-1D-DNA.html)

* [Albacore_all_RNA](https://a-slide.github.io/pycoQC/demo/data/output/Albacore_all_RNA.html)

* [Guppy-2.1.3_basecall-1D_DNA_barcode](https://a-slide.github.io/pycoQC/demo/data/output/Guppy-2.1.3_basecall-1D_DNA_barcode.html)

* [Guppy-2.1.3_basecall-1D_RNA](https://a-slide.github.io/pycoQC/demo/data/output/Guppy-2.1.3_basecall-1D_RNA.html)

## Authors

* Adrien Leger - aleg {at} ebi.ac.uk

* Tommaso Leonardi - tom {at} tleo.io
